@@ -20,6 +20,14 @@ class ExerciseWindow : public QMainWindow
 public:
     explicit ExerciseWindow(QWidget *parent = 0);
     void loadExercise(QList<QString> name);
+
+signals:
+    void closed();
+    void landscape();
+
+public slots:
+    void sendClosed();
+
 private:
     SettingsWindow *sw;
     NewExerciseWindow *nw;
