@@ -78,7 +78,7 @@ void InfoWindow::sendLandscape()
 void InfoWindow::orientationChanged()
 {
     QRect screenGeometry = QApplication::desktop()->screenGeometry();
-
+    QString str;
     if (screenGeometry.width() > screenGeometry.height())
     {
         w = 760;
@@ -93,11 +93,17 @@ void InfoWindow::orientationChanged()
 
     if(i == 1)
     {
-        bild.load("/home/user/MyDocs/" + exerciseName + "1.png");
+        str = "/home/user/MyDocs/" + exerciseName + "1.png";
+        str.replace(QString(" "), QString(""));
+
+        bild.load(str);
     }
     else if(i == 2)
     {
-        bild.load("/home/user/MyDocs/" + exerciseName + "2.png");
+        str = "/home/user/MyDocs/" + exerciseName + "2.png";
+        str.replace(QString(" "), QString(""));
+
+        bild.load(str);
     }
     bild = bild.scaled(w,h,Qt::KeepAspectRatio);
     lblInfo->setAlignment(Qt::AlignCenter);
