@@ -70,7 +70,6 @@ void ListWindow::loadExercises(QString grp)
 
 void ListWindow::showInfo(QModelIndex index)
 {
-    setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
     if(index.data().toString() == "No exercises")
         return;
 
@@ -86,9 +85,11 @@ void ListWindow::showInfo(QModelIndex index)
     }
     else
     {
+
         imw = new InfoMotionWindow(this);
         connect(imw,SIGNAL(closed()),this,SLOT(sendClosed()));
         connect(imw,SIGNAL(landscape()),this, SLOT(sendLandscape()));
+        qDebug() << "b";
         imw->loadMotionExercise(index.data().toString());
         imw->show();
     }
