@@ -25,14 +25,14 @@ StartWindow::StartWindow(QWidget *parent) :
     hLabelLayout->addWidget(lblCardio);
 
     QHBoxLayout *hButtonLayout = new QHBoxLayout;
-    btnWeight = new QPushButton("Weight-lifting");
+    btnWeight = new QPushButton(QIcon(":/images/images/weight.png"),"",this);
     connect(btnWeight,SIGNAL(clicked()),this,SLOT(showWeight()));
 
-    btnCardio = new QPushButton("Cardio");
+    btnCardio = new QPushButton(QIcon(":/images/images/cardio.png"),"",this);
     connect(btnCardio,SIGNAL(clicked()),this,SLOT(showCardio()));
-    btnProgram = new QPushButton("Program");
+    btnProgram = new QPushButton(QIcon(":/images/images/program.png"),"",this);
 
-    btnFood = new QPushButton("Food");
+    btnFood = new QPushButton(QIcon(":/images/images/food.png"),"",this);
     connect(btnFood,SIGNAL(clicked()),this, SLOT(showFood()));
 
     hButtonLayout->addWidget(btnWeight);
@@ -53,8 +53,8 @@ StartWindow::StartWindow(QWidget *parent) :
     QList <QString> tmp = getStats();
     if(!tmp.isEmpty())
     {
-        lblWeight->setText("Weight-lift/week \n " + tmp.takeFirst() + "kg \n "+ tmp.takeFirst() + "times in total");
-        lblCardio->setText("Cardio/week \n" + tmp.takeFirst() + "km \n" + tmp.takeFirst() + "times in total");
+        lblWeight->setText("Weight-lift \n " + tmp.takeFirst() + "kg/week \n "+ tmp.takeFirst() + "times/week");
+        lblCardio->setText("Cardio \n" + tmp.takeFirst() + "km/week \n" + tmp.takeFirst() + "times/week");
     }
 
     resize(480,720);
@@ -71,11 +71,14 @@ QList <QString> StartWindow::getStats()
 {
     QList < QList <QString> > list;
     QList <QString> tmp, stats;
-    double km = 0;
-    int countW = 0, countC = 0, kg = 0;
-    QString strKg, strKm, strCountW, strCountC;
+    double countW = 0, countC = 0, kg = 0, km = 0;
+    int weeks;
 
-    list = xml->readHistory();
+    list = xml->readHistory(); //Hmtar alla gjorda vningar
+    //Grupp
+    //Namn
+    //Variabel
+    //Dag
     while(!list.isEmpty())
     {
         tmp = list.takeFirst();
@@ -94,20 +97,51 @@ QList <QString> StartWindow::getStats()
         }
     }
 
-    strKg.setNum(kg);
-    strKm.setNum(km);
-    strCountW.setNum(countW);
-    strCountC.setNum(countC);
 
-    stats.append(strKg);
-    stats.append(strCountW);
-    stats.append(strKm);
-    stats.append(strCountC);
+    weeks = weeksExercise();
+
+
+    kg /= weeks;
+    km /= weeks;
+    countW /= weeks;
+    countC /= weeks;
+
+    stats.append(QString::number(kg,'f',0));
+    stats.append(QString::number(countW,'f',1));
+    stats.append(QString::number(km,'f',2));
+    stats.append(QString::number(countC,'f',1));
+
+
 
     return stats;
 
 }
 
+
+int StartWindow::weeksExercise()
+{
+    QList <QString> dates = xml->getDates();
+    if(dates.isEmpty())
+        return 1;
+
+    QDate current, last;
+    QString tmp;
+    int weeks = 0;
+
+    current = QDate::currentDate();
+
+    tmp = dates.last();
+    tmp.replace("-","");
+
+    last = last.fromString(tmp,"ddMMyyyy");
+    weeks = current.daysTo(last);
+    weeks = weeks / 7 -1;
+    weeks *= -1;
+
+    return weeks;
+}
+
+
 StartWindow::~StartWindow()
 {
 
@@ -152,8 +186,8 @@ void StartWindow::changeEvent(QEvent *event)
 
         if(!tmp.isEmpty())
         {
-            lblWeight->setText("Weight-lift/week \n " + tmp.takeFirst() + "kg \n "+ tmp.takeFirst() + "times in total");
-            lblCardio->setText("Cardio/week \n" + tmp.takeFirst() + "km \n" + tmp.takeFirst() + "times in total");
+            lblWeight->setText("Weight-lift \n " + tmp.takeFirst() + " kg/week \n "+ tmp.takeFirst() + " times/week");
+            lblCardio->setText("Cardio \n" + tmp.takeFirst() + " km/week \n" + tmp.takeFirst() + " times/week");
         }
     }
 }
