@@ -2,7 +2,9 @@
 #include <QDateTime>
 #include <QtXml>
 #include <QMessageBox>
-#include <QtDebug> // qDebug() << "3";
+#include <QtDebug>
+#include <QtGui/QApplication>
+
 XML::XML()
 {
 
@@ -13,7 +15,8 @@ void XML::removeElement(QString name)
 {
 
     QDomDocument doc( "Exercises" );
-    QFile file( "/home/user/MyDocs/exercises.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/exercises.xml" );
 
     if( !file.open( QIODevice::ReadOnly ) )
       return;
@@ -57,7 +60,8 @@ void XML::removeElement(QString name)
 void XML::saveProgram(QString name, QList <QString> exercises)
 {
     QDomDocument doc( "Program" );
-    QFile file( "/home/user/MyDocs/program.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/program.xml" );
     file.open( QIODevice::ReadOnly );
     doc.setContent( &file );
 
@@ -105,7 +109,8 @@ QList <QString> XML::loadProgram(QString name)
     QList <QString> readInfo;
 
     QDomDocument doc( "Program" );
-    QFile file( "/home/user/MyDocs/program.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/program.xml" );
     if( !file.open( QIODevice::ReadOnly ) )
     {
         return readInfo;
@@ -156,7 +161,8 @@ void XML::saveSettings(QString vibrate, QString sound, QString volume,
 
     root.appendChild(createSettingsNode(doc, vibrate, sound, volume, set, reps1, reps2, reps3, currentReps, min, sec, calories));
 
-    QFile file( "/home/user/MyDocs/settings.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/settings.xml" );
     if(!file.open(QIODevice::WriteOnly))
         return;
 
@@ -172,7 +178,8 @@ QList <QString> XML::loadSettings()
     QList <QString> readInfo;
 
     QDomDocument doc( "Settings" );
-    QFile file( "/home/user/MyDocs/settings.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/settings.xml" );
     if( !file.open( QIODevice::ReadOnly ) )
     {
         return readInfo;
@@ -220,7 +227,8 @@ void XML::saveDoneEx(QString group, QString name, QString kg, QString currentRep
     QString dateString = date.toString("dd-MM-yyyy");
 
     QDomDocument doc( "Exercises" );
-    QFile file( "/home/user/MyDocs/history.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/history.xml" );
     file.open( QIODevice::ReadOnly );
     doc.setContent( &file );
 
@@ -287,7 +295,8 @@ QList<QString> XML::getDates()
     QList <QString> readInfo;
 
     QDomDocument doc( "Exercises" );
-    QFile file( "/home/user/MyDocs/history.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/history.xml" );
     if( !file.open( QIODevice::ReadOnly ) )
     {
         return readInfo;
@@ -337,7 +346,8 @@ QList < QList<QString> > XML::getHistoryByDate(QString date)
     QList <QString> readInfo;
 
     QDomDocument doc( "Exercises" );
-    QFile file( "/home/user/MyDocs/history.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/history.xml" );
     if( !file.open( QIODevice::ReadOnly ) )
     {
         return list;
@@ -384,7 +394,8 @@ QList< QList<QString> > XML::readHistory()
     QList <QString> readInfo;
 
     QDomDocument doc( "Exercises" );
-    QFile file( "/home/user/MyDocs/history.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/history.xml" );
     if( !file.open( QIODevice::ReadOnly ) )
     {
         return list;
@@ -491,7 +502,8 @@ void XML::saveEx(QString name, QString group, QString muscle,
                     QString info)
 {
     QDomDocument doc( "Exercises" );
-    QFile file( "/home/user/MyDocs/exercises.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/exercises.xml" );
     file.open( QIODevice::ReadOnly);
     doc.setContent( &file );
 
@@ -546,7 +558,8 @@ void XML::saveCardio(QString name)
 {
 
     QDomDocument doc( "Exercises" );
-    QFile file( "/home/user/MyDocs/cardio.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/cardio.xml" );
     file.open( QIODevice::ReadOnly );
     doc.setContent( &file );
 
@@ -605,7 +618,8 @@ void XML::saveEatenFood(QString kcal, QString protein, QString carbohydrate, QSt
     QString dateString = date.toString("dd-MM-yyyy");
 
     QDomDocument doc( "Calories" );
-    QFile file( "/home/user/MyDocs/calories.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/calories.xml" );
     file.open( QIODevice::ReadOnly );
     doc.setContent( &file );
 
@@ -642,7 +656,8 @@ QList <int> XML::getTodaysCalories()
     int kcal = 0, protein = 0, carbohydrate = 0, fat = 0;
 
     QDomDocument doc( "Calories" );
-    QFile file( "/home/user/MyDocs/calories.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/calories.xml" );
     if( !file.open( QIODevice::ReadOnly ) )
     {
       return list;
@@ -704,7 +719,8 @@ QList <int> XML::getCaloriesByName(QString name)
     QString readInfo;
 
     QDomDocument doc( "Ingredients" );
-    QFile file( "/home/user/MyDocs/ingredients.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/ingredients.xml" );
 
     if( !file.open( QIODevice::ReadOnly ) )
       return list;
@@ -753,7 +769,8 @@ void XML::saveFood(QString name, QString type, QString kcal, QString protein, QS
 {
 
     QDomDocument doc( "Ingredients" );
-    QFile file( "/home/user/MyDocs/ingredients.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/ingredients.xml" );
     file.open( QIODevice::ReadOnly );
     doc.setContent( &file );
     file.close();
@@ -809,7 +826,8 @@ void XML::saveFood(QString name, QString type, QString kcal, QString protein, QS
 void XML::updateLastWeight(QString name, QString weight, QString status, QString reps)
 {
     QDomDocument doc( "Exercises" );
-    QFile file( "/home/user/MyDocs/exercises.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/exercises.xml" );
     if( !file.open( QIODevice::ReadWrite ) )
       return;
     if( !doc.setContent( &file ) )
@@ -866,7 +884,8 @@ void XML::updateLastWeight(QString name, QString weight, QString status, QString
 void XML::updateLastDistance(QString name, QString distance, QString min, QString sec, QString status)
 {
     QDomDocument doc( "Cardio" );
-    QFile file( "/home/user/MyDocs/cardio.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/cardio.xml" );
     if( !file.open( QIODevice::ReadWrite ) )
       return;
     if( !doc.setContent( &file ) )
@@ -1012,7 +1031,8 @@ QList<QString> XML::openEx(QString name)
     QList<QString> readInfo;
 
     QDomDocument doc( "Exercises" );
-    QFile file( "/home/user/MyDocs/exercises.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/exercises.xml" );
 
     if( !file.open( QIODevice::ReadOnly ) )
       return readInfo;
@@ -1068,7 +1088,8 @@ QList<QString> XML::openCardio(QString name)
     QList<QString> readInfo;
 
     QDomDocument doc( "Exercises" );
-    QFile file( "/home/user/MyDocs/cardio.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/cardio.xml" );
 
     if( !file.open( QIODevice::ReadOnly ) )
       return readInfo;
@@ -1118,7 +1139,8 @@ QList<QString> XML::openGroup(QString group)
     readInfo.clear();
 
     QDomDocument doc( "Exercises" );
-    QFile file( "/home/user/MyDocs/exercises.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/exercises.xml" );
 
     if( !file.open( QIODevice::ReadOnly ) )
     {
@@ -1162,7 +1184,8 @@ QList<QString> XML::openIngredients()
     readInfo.clear();
 
     QDomDocument doc( "Ingredients" );
-    QFile file( "/home/user/MyDocs/ingredients.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/ingredients.xml" );
 
     if( !file.open( QIODevice::ReadOnly ) )
     {
@@ -1201,7 +1224,8 @@ QList<QString> XML::openCardio()
     readInfo.clear();
 
     QDomDocument doc( "Cardio" );
-    QFile file( "/home/user/MyDocs/cardio.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/cardio.xml" );
 
     if( !file.open( QIODevice::ReadOnly ) )
     {
@@ -1241,7 +1265,8 @@ QList<QString> XML::openAll()
     readInfo.clear();
 
     QDomDocument doc( "Exercises" );
-    QFile file( "/home/user/MyDocs/exercises.xml" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/exercises.xml" );
     if( !file.open( QIODevice::ReadOnly ) )
     {
         readInfo.append("file");
